@@ -15,7 +15,6 @@
 #include "prefs.h"
 
 #include <Akonadi/CalendarUtils>
-#include <Akonadi/ETMCalendar>
 #include <Akonadi/IncidenceChanger>
 #include <CalendarSupport/Utils>
 
@@ -56,7 +55,7 @@ public:
     {
     }
 
-    Q_REQUIRED_RESULT int todayColumn() const;
+    [[nodiscard]] int todayColumn() const;
 
 public:
     EventView *const mEventView;
@@ -269,7 +268,7 @@ public:
 
     // Working Hour coordinates
     bool mWorkingHoursEnable;
-    QVector<bool> *mHolidayMask = nullptr;
+    QList<bool> *mHolidayMask = nullptr;
     int mWorkingHoursYTop;
     int mWorkingHoursYBottom;
 
@@ -580,11 +579,7 @@ bool Agenda::eventFilter_drag(QObject *obj, QDropEvent *de)
         de->setDropAction(Qt::MoveAction);
 
         QWidget *dropTarget = qobject_cast<QWidget *>(obj);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        QPoint dropPosition = de->pos();
-#else
         QPoint dropPosition = de->position().toPoint();
-#endif
         if (dropTarget && dropTarget != this) {
             dropPosition = dropTarget->mapTo(this, dropPosition);
         }
@@ -970,7 +965,7 @@ void Agenda::performItemAction(QPoint pos)
                 KMessageBox::information(this,
                                          i18n("Unable to lock item for modification. "
                                               "You cannot make any changes."),
-                                         i18n("Locking Failed"),
+                                         i18nc("@title:window", "Locking Failed"),
                                          QStringLiteral("AgendaLockingFailed"));
                 d->mScrollUpTimer.stop();
                 d->mScrollDownTimer.stop();
@@ -1166,8 +1161,7 @@ void Agenda::endItemAction()
         }
 
         Akonadi::Item item = d->mCalendar->item(incidence);
-
-        if (incidence->recurs()) {
+        if (incidence && incidence->recurs()) {
             const int res = d->mAgendaView->showMoveRecurDialog(incidence, recurrenceId.date());
 
             if (!d->mActionItem) {
@@ -1210,7 +1204,7 @@ void Agenda::endItemAction()
                     KMessageBox::error(this,
                                        i18n("Unable to add the exception item to the calendar. "
                                             "No change will be done."),
-                                       i18n("Error Occurred"));
+                                       i18nc("@title:window", "Error Occurred"));
                 }
                 break;
             }
@@ -1498,7 +1492,7 @@ void Agenda::drawContents(QPainter *p, int cx, int cy, int cw, int ch)
     // If busy day, use busy color
     // if work and busy day, mix both, and busy color has alpha
 
-    const QVector<bool> busyDayMask = d->mAgendaView->busyDayMask();
+    const QList<bool> busyDayMask = d->mAgendaView->busyDayMask();
 
     // Highlight working hours
     if (d->mWorkingHoursEnable && d->mHolidayMask) {
@@ -1699,9 +1693,9 @@ QTime Agenda::gyToTime(int gy) const
     return time;
 }
 
-QVector<int> Agenda::minContentsY() const
+QList<int> Agenda::minContentsY() const
 {
-    QVector<int> minArray;
+    QList<int> minArray;
     minArray.fill(timeToY(QTime(23, 59)), d->mSelectedDates.count());
     for (const AgendaItem::QPtr &item : std::as_const(d->mItems)) {
         if (item) {
@@ -1718,9 +1712,9 @@ QVector<int> Agenda::minContentsY() const
     return minArray;
 }
 
-QVector<int> Agenda::maxContentsY() const
+QList<int> Agenda::maxContentsY() const
 {
-    QVector<int> maxArray;
+    QList<int> maxArray;
     maxArray.fill(timeToY(QTime(0, 0)), d->mSelectedDates.count());
     for (const AgendaItem::QPtr &item : std::as_const(d->mItems)) {
         if (item) {
@@ -2290,7 +2284,7 @@ void Agenda::setIncidenceChanger(Akonadi::IncidenceChanger *changer)
     d->mChanger = changer;
 }
 
-void Agenda::setHolidayMask(QVector<bool> *mask)
+void Agenda::setHolidayMask(QList<bool> *mask)
 {
     d->mHolidayMask = mask;
 }
@@ -2347,3 +2341,5 @@ Agenda *AgendaScrollArea::agenda() const
 {
     return mAgenda;
 }
+
+#include "moc_agenda.cpp"
